summaryrefslogtreecommitdiffstats
path: root/kjsembed/bindings/dcop_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/bindings/dcop_imp.h')
-rw-r--r--kjsembed/bindings/dcop_imp.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/kjsembed/bindings/dcop_imp.h b/kjsembed/bindings/dcop_imp.h
index 6a821028..ca20fdca 100644
--- a/kjsembed/bindings/dcop_imp.h
+++ b/kjsembed/bindings/dcop_imp.h
@@ -48,22 +48,22 @@ class JSDCOPInterfacerLoader : public JSBindingBase
};
/**
* TQObject Binding for a DCOP interface
*/
class JSDCOPInterface : public BindingObject, public DCOPObject
{
Q_OBJECT
public:
- JSDCOPInterface( KJS::Interpreter *js, TQObject *parent, const char *name=0 );
+ JSDCOPInterface( KJS::Interpreter *js, TTQObject *parent, const char *name=0 );
virtual ~JSDCOPInterface();
- QCStringList functionsDynamic();
- bool processDynamic (const TQCString &fun, const TQByteArray &data, TQCString &replyType, TQByteArray &replyData);
+ TQCStringList functionsDynamic();
+ bool processDynamic (const TTQCString &fun, const TTQByteArray &data, TTQCString &replyType, TTQByteArray &replyData);
public slots:
- void publish(const TQString& signature);
+ void publish(const TTQString& signature);
private:
- QCStringList m_Members;
+ TQCStringList m_Members;
KJS::Interpreter *m_js;
};
@@ -123,23 +123,23 @@ public:
/** Invokes the call function. */
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
- static KJS::Value demarshall( KJS::ExecState * exec, const TQCString& type, TQDataStream& data);
- static TQVariant demarshall( const TQCString &type, TQDataStream &ds);
- static void marshall( const TQVariant& data, const TQString &typeName, TQByteArray& buffer );
- static TQStringList getTypes( const TQString& function);
+ static KJS::Value demarshall( KJS::ExecState * exec, const TTQCString& type, TTQDataStream& data);
+ static TTQVariant demarshall( const TTQCString &type, TTQDataStream &ds);
+ static void marshall( const TTQVariant& data, const TTQString &typeName, TTQByteArray& buffer );
+ static TTQStringList getTypes( const TTQString& function);
bool attach() const;
bool detach() const;
bool isAttached() const;
- TQString dcopStart( const TQString& appName, const TQStringList& args);
- TQStringList registeredApplications();
- TQStringList remoteObjects( const TQString& remApp);
- TQStringList remoteInterfaces( const TQString& remApp, const TQString& remObj );
- TQStringList remoteFunctions( const TQString& remApp, const TQString& remObj);
- bool connectDCOPSignal (const TQString &sender, const TQString &senderObj, const TQString &signal, const TQString &receiverObj, const TQString &slot, bool Volatile = false);
- bool disconnectDCOPSignal (const TQString &sender, const TQString &senderObj, const TQString &signal, const TQString &receiverObj, const TQString &slot);
+ TTQString dcopStart( const TTQString& appName, const TTQStringList& args);
+ TTQStringList registeredApplications();
+ TTQStringList remoteObjects( const TTQString& remApp);
+ TTQStringList remoteInterfaces( const TTQString& remApp, const TTQString& remObj );
+ TTQStringList remoteFunctions( const TTQString& remApp, const TTQString& remObj);
+ bool connectDCOPSignal (const TTQString &sender, const TTQString &senderObj, const TTQString &signal, const TTQString &receiverObj, const TTQString &slot, bool Volatile = false);
+ bool disconnectDCOPSignal (const TTQString &sender, const TTQString &senderObj, const TTQString &signal, const TTQString &receiverObj, const TTQString &slot);
KJS::Value dcopCall(KJS::ExecState *exec, KJS::Object &, const KJS::List &args);
KJS::Value dcopSend(KJS::ExecState *exec, KJS::Object &, const KJS::List &args);
private:
@@ -48,22 +48,22 @@ class JSDCOPInterfacerLoader : public JSBindingBase
};
/**
-* TQObject Binding for a DCOP interface
+* TTQObject Binding for a DCOP interface
*/
class JSDCOPInterface : public BindingObject, public DCOPObject